@@ -58,7 +58,7 @@ init_fextra_stmt(plch_fextra *fextra,
 	 */
 	fextra->parentids[stmtid] = parentid;
 	fextra->naturalids[stmtid] = ++(*naturalid);
-	fextra->levels[stmtid] = level;
+	fextra->levels[stmtid] = level++;
 
 	fextra->natural_to_ids[fextra->naturalids[stmtid] - 1] = stmtid;
 
@@ -66,7 +66,6 @@ init_fextra_stmt(plch_fextra *fextra,
 		fextra->max_deep = cur_deep;
 
 	cur_deep++;
-	level++;
 
 	switch (stmt->cmd_type)
 	{
@@ -187,6 +186,34 @@ fextra_init_hk(plch_fextra_hk *hk, PLpgSQL_function *func)
 
 }
 
+static void
+pin_func(PLpgSQL_function *func)
+{
+#if PG_VERSION_NUM >= 180000
+
+	func->cfunc.use_count++;
+
+#else
+
+	func->use_count++;
+
+#endif
+}
+
+static void
+unpin_func(PLpgSQL_function *func)
+{
+#if PG_VERSION_NUM >= 180000
+
+	func->cfunc.use_count--;
+
+#else
+
+	func->use_count--;
+
+#endif
+}
+
 
 static void
 fextra_CacheObjectCallback(Datum arg, int cacheid, uint32 hashValue)
@@ -207,17 +234,6 @@ fextra_CacheObjectCallback(Datum arg, int cacheid, uint32 hashValue)
 
 		if (!fextra->is_valid && fextra->use_count == 0)
 		{
-
-#if PG_VERSION_NUM >= 180000
-
-			fextra->func->cfunc.use_count--;
-
-#else
-
-			fextra->func->use_count--;
-
-#endif
-
 			MemoryContextDelete(fextra->mcxt);
 			if (hash_search(fextra_ht,
 							&fextra->hk,
@@ -269,17 +285,6 @@ plch_get_fextra(PLpgSQL_function *func)
 
 		if (found && !fextra->is_valid && fextra->use_count == 0)
 		{
-
-#if PG_VERSION_NUM >= 180000
-
-			fextra->func->cfunc.use_count--;
-
-#else
-
-			fextra->func->use_count--;
-
-#endif
-
 			MemoryContextReset(fextra->mcxt);
 		}
 
@@ -340,21 +345,12 @@ plch_get_fextra(PLpgSQL_function *func)
 		fextra->max_deep = 0;
 		init_fextra_stmt(fextra, 0, &naturalid, 1, 0, (PLpgSQL_stmt *) func->action);
 
-#if PG_VERSION_NUM >= 180000
-
-		func->cfunc.use_count++;
-
-#else
-
-		func->use_count++;
-
-#endif
-
 		fextra->func = func;
 
 		fextra->is_valid = true;
 	}
 
+	pin_func(fextra->func);
 	fextra->use_count++;
 
 	return fextra;
@@ -368,18 +364,8 @@ plch_release_fextra(plch_fextra *fextra)
 	/* until now, referenced PLpgSQL_function should be still valid */
 	Assert(fextra->hk.fn_oid == fextra->func->fn_oid);
 
+	unpin_func(fextra->func);
 	fextra->use_count--;
-
-#if PG_VERSION_NUM >= 180000
-
-	fextra->func->cfunc.use_count--;
-
-#else
-
-	fextra->func->use_count--;
-
-#endif
-
 }
 
 
